(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    111310,       2243]*)
(*NotebookOutlinePosition[    112303,       2275]*)
(*  CellTagsIndexPosition[    112259,       2271]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["\n", "Text"],
  StyleBox["VERIPATH 1.3", "Text",
    FontSize->12,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n\n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["Pedigree:  Niels Waller\n                Vanderbilt University\n  \
              niels.waller@vanderbilt.edu\n                Feb, 2001", "Text",
    
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n   \n ", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["Revised:  July, 2001   Added correlation bounds and time \
constraints\n                 November 2001 Added generation of LISREL \
command files", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n                \n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["Program code to accompany:", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n                 ", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["The Path Analysis Controversy: A New Statistical Approach\n       \
                     to Strong Appraisal of Verisimilitude\n                  \
                 ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n               ", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["   Paul E. Meehl and Niels G. Waller", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n\n\n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["VERIPATH is a ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["Mathematica", "Text",
    CellFrame->True,
    FontSize->12,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox[" Notebook  (i.e., you  need ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["Mathematica", "Text",
    CellFrame->True,
    FontSize->12,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox[" to run this program).", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n\n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["VERIPATH uses a LISREL like input specification  with matrices \
(1) sigma, (2) beta, and (3) gamma.  ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n\n", "Text",
    CellFrame->True,
    FontSize->14,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["The observed  correlation  matrix, sigma,  must be partitioned  \
such that  endogenous   variables appear first ( a function is provided  to  \
reorder a correlation matrix).        ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n\n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["We partition  the observed  correlation  matrix into p endogenous \
  variables  and q exogeneous  variables.\nExogenous variables are labelled x \
                                                                              \
                          \nEndogeneous variables are labelled y   ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["  ", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["                                                                  \
                              \n\n", "Text",
    CellFrame->True,
    FontSize->14,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["A path from an endogeneous to an endogeneous variable is \
specified in matrix beta .   \nA path from an exogenous to an endogeneous \
variable is specified in  matrix gamma . ", "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["                                                    \n            \
                               \n", "Text",
    CellFrame->True,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["printOutput = \"LONG\" provides detailed output for all \
alternative models \n(as defined by Meehl & Waller. Note: this can be a great \
deal of output)\nprintOutput = \"SHORT\" provides summary information, only.",
     "Text",
    CellFrame->True,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  StyleBox["\n\n\n", "Text"],
  StyleBox["Please submit all questions, problems, or bug-reports to Niels \
Waller:  niels.waller@vanderbilt.edu", "Text",
    FontSize->10],
  StyleBox["\n", "Text"],
  StyleBox["VERIPATH", "Text",
    FontSize->10],
  StyleBox[" ", "Text"],
  "is free software and comes with ABSOLUTELY NO WARRANTY.",
  StyleBox[" ", "Text"]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->RGBColor[0.789075, 0.996109, 0.996109]],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Off[General::spell];\)\), "\n", 
    \(\(Off[General::spell1];\)\)}], "Input",
  CellOpen->False,
  InitializationCell->True,
  FontSize->9],

Cell[TextData[{
  "    ",
  StyleBox["Beginning of Input Section:",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\n\(SetDirectory["\<D:\Projects\FrontBurner\MeehlWaller\Examples\BUD\>"]\
;\)\), "\n", 
    \(\(<< RodgersInA.txt;\)\)}], "Input",
  FontSize->9],

Cell[TextData[{
  " ",
  StyleBox["End of Input Section ",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell["Function Definitions", "Text",
  FontSize->9,
  Background->RGBColor[0, 0.996109, 0.250004]],

Cell[TextData[{
  "FUNCTION: ",
  StyleBox["reOrderSigma",
    FontColor->RGBColor[0, 0, 1]],
  "[sigmaIn, newOrder]\nA simple function to reorder rows and columns of \
sigma.\n",
  StyleBox["newOrder",
    FontColor->RGBColor[0, 0, 1]],
  " is a vector that specifies the variable order in the re-ordered matrix.  \
For instance, if the input order of sigmaIn\n was A, B, C, and you wanted to \
reorder variables B and C, you would define ",
  StyleBox["newOrder",
    FontColor->RGBColor[0, 0, 1]],
  " as follows:  ",
  StyleBox["newOrder={1,3,2}",
    FontColor->RGBColor[0, 0, 1],
    Background->RGBColor[1, 1, 0]],
  ";\n\nExample 2.  Assume you have 7 variables\nThe old order is (by \
definition)                   1     2     3      4     5    6    7\nSuppose \
you want a new order:                  1     3     5      4     2   7    6\n\
Defining newOrder as: newOrder={1,3,5,4,2,7,6}\nwould keep old var 1 in \
position 1\nold var 2 would be in position 3\nold var 3 would be in position \
5\nold var 4 would remain in position 4\nold var 5 would be in position 2\n\
old var 6 would be in position 7\nold var 7 would be in position 6"
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell["\<\
 reOrderSigma[sigmaA_, newOrder_] := Module[{i, j, nVar}, 
    nVar = Dimensions[sigmaA][[1]]; sigmaB = Table[0, {nVar}, {nVar}]; 
     For[i = 1, i <= nVar, i++, For[j = 1, j <= nVar, j++, 
       sigmaB[[newOrder[[i]],newOrder[[j]]]] = sigmaA[[i,j]]; ]]; sigmaB]; \
\>", "Input",
  FontSize->9],

Cell[TextData[StyleBox["Miscellaneous Functions ",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    StyleBox[\(mkCoef[l_, n_] := {\ Rule[l, n]};\),
      FontSize->9], "\n", 
    StyleBox[\(rnd[x_] := N[Round[x*1000]/1000];\),
      FontSize->9], "\n", 
    StyleBox[\(TF[x_] := TraditionalForm[x];\),
      FontSize->9], "\n", 
    StyleBox[\(OF[x_] := OutputForm[x];\),
      FontSize->9], "\n", 
    StyleBox[\(PF[x_] := PaddedForm[x, {6, 3}];\),
      FontSize->9], "\n", 
    StyleBox[\(blank = TF["\<\n \>"];\),
      FontSize->9]}], "Input"],

Cell[TextData[{
  "FUNCTION:        ",
  StyleBox[" fitModel [Bmat, Gmat, Smat, cors, modelNum]",
    FontColor->RGBColor[0, 0, 1]],
  "\nThis is the main function.  ",
  StyleBox["fitModel",
    FontColor->RGBColor[0, 0, 1]],
  "  solves a systems on nonlinear polynomials that are entailed by a Path \
Analysis Model.\nArguments:\n        Bmat           matrix beta \n        \
Gmat          matrix gamma\n        Smat          observed correlation matrix\
\n        cors           a List of correlations to be used as right hand \
variables in the polynomial equations \n\nFunction Returns:\n        SigmaHat \
   predicted correlation matrix using path coefficients from polynomial \
equations\n        corList        a List of correlations used as right hand \
variables in polynomial equations (same as cors)\n        polynomial  a \
symbolic representation of the model implied polynomial equations\n        \
PathCoef    path coefficients calculated by solving the polynomial equations\n\
        fitindex       the root mean square r as defined in Meehl & Waller\n  \
      Smat          observed correlation matrix\n   "
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", "   ", 
      RowBox[{\(fitModel[Bmat_, \ Gmat_, \ Smat_, cors_]\), ":=", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({SigmaHat, Sigmayy, \ Sigmaxy, \ 
              Sigmayx, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ Phi, \ 
              Imat, \ IminusB, \ polynomial, PathCoef, fitIndex}\), ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            RowBox[{\(PathCoef =. \), ";", " ", \(tempPath =. \), ";", 
              " ", \(coefficients =. \), ";", 
              "\[IndentingNewLine]", \(SigmaHat =. \), ";", 
              " ", \(polynomial =. \), ";", " ", \(Psi =. \), ";", 
              " ", \(Phi =. \), ";", "\[IndentingNewLine]", \(Psitemp =. \), 
              ";", " ", \(i =. \), ";", " ", \(x =. \), ";", 
              " ", \(GinModel =. \), ";", \(sv =. \), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(Nx = \(Dimensions[Gmat]\)[\([2]\)]\), 
              ";", "\n", "    ", \(Ny = \(Dimensions[Bmat]\)[\([1]\)]\), ";", 
              "\n", "\[IndentingNewLine]", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", \( (*\ 
                this\ will\ select\ the\ \(coefficients\ --\)\ i . e . , \ 
                non - zero\ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\ 
                entries\ from\ Gmat\ and\ Bmat\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\ \(let\ x = {a, 0, b, 
                    0}\)\(,\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\ 
                then\ \ Select[x, 
                    FreeQ[#, 
                        0] &]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              StyleBox[" ",
                FontSize->9], "\n", 
              "    ", \( (*\ 
                will\ return\ \ \ {a, 
                    b}\ \ \ \ \ \ \ \ \ \ see\ page\ 123\ The\ M\ Book\ \ \ \ \
\ \ \ \ \ \ \ \ \ *) \), "  ", "\n", 
              "    ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\n", "\n", 
              "      ", \(coefficients = 
                Join[\ Select[Flatten[Gmat], 
                    FreeQ[#, 0] &], \[IndentingNewLine]\ 
                  Select[Flatten[Bmat], FreeQ[#, 0] &]]\), ";", "  ", "\n", 
              "\n", "   ", "\n", "      ", \(Ntot = Nx\  + \ Ny\), ";", "\n", 
              "      ", \(Npaths = \(Dimensions[coefficients]\)[\([1]\)]\), 
              ";", 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 0]], "   ", 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)*) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*Create\ a\ matrix\ of\ place\ holders\ for\ the\ \
observed\ correlations\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\( (*and\ insert\ ones\ on\ the\ diagonal\ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)*) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(xyrows = Table[x, {x, 1, Ny}]\), ";", 
              "\n", "     ", \(xxrows = Table[x, {x, Ny + 1, Ntot}]\), ";", 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 0]], "  ", 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\( (*Sigmayx\ contains\ the\ correlations\ between\ \
the\ endogenous\ variables\ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*and\ the\ exogenous\ variables . \ 
                      Sigmayy\ contains\ the\ correlations\ \ \ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["  ",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\( (*among\ the\ endogenous\ variables\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              
              StyleBox[\( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              " ", \(Sigmaxy = Smat[\([xxrows, xyrows]\)]\), ";", 
              "\[IndentingNewLine]", 
              " ", \(Sigmayx = Smat[\([xyrows, xxrows]\)]\), ";", "\n", 
              "     ", \(Sigmayy = Smat[\([xyrows, xyrows]\)]\), ";", 
              "\[IndentingNewLine]", "\n", 
              " ", \(Phi = Smat[\([xxrows, xxrows]\)]\), ";", "\n", 
              "     ", \(Imat = IdentityMatrix[Ny]\), ";", "\n", 
              "\[IndentingNewLine]", "     ", \(IminusB = Imat\  - \ Bmat\), 
              ";", "\n", "     ", \(IBinv = Inverse[Imat - Bmat]\), ";", 
              "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              " ", \( (*\ \ \ \ \ \ \ \ \ \ \ \ \ Begin : \ 
                  Derive\ elements\ of\ PSI\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
*) \), "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "    ", \(Psitemp = Table[0, {Ny}]\), ";", 
              "\[IndentingNewLine]", "    ", \(GinModel = Table[0, {Nx}]\), 
              ";", " ", \( (*\ 
                are\ all\ X\ variables\ in\ the\ \(\(model\)\(?\)\)\ *) \), 
              "\[IndentingNewLine]", 
              "          ", \(For[i = \ 1, \ 
                i \[LessEqual] 
                  Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(For[j = 1, \ j \[LessEqual] 
                      Ny, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(If[\(! NumericQ[
                            Bmat[\([i, 
                                j]\)]]\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \(Psitemp[\([i]\)] = 
                            Psitemp[\([i]\)] + \ 
                              Bmat[\([i, j]\)]*
                                Smat[\([i, 
                                    j]\)];\)\[IndentingNewLine]\ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ ];\)\
\[IndentingNewLine]\ \ \ \ \ \ \ ]\), ";", " ", "\[IndentingNewLine]", "\n", 
              "           ", \(For[i = \ 1, \ 
                i \[LessEqual] 
                  Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(For[j = 1, \ j \[LessEqual] 
                      Nx, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(If[\(! NumericQ[
                            Gmat[\([i, 
                                j]\)]]\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \
\ \ \ \ Psitemp[\([i]\)] = 
                          Psitemp[\([i]\)] + \ 
                            Gmat[\([i, j]\)]*
                              Smat[\([i, \((j + 
                                      Ny)\)]\)]; \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \ \ \ GinModel[\([j]\)] = 
                          1;\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ ];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \ \ \
\ \ \ ]\), ";", "      ", "\n", "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "      ", \( (*\ \(We\ assume\ that\ Psi\ is\ a\ diagonal\ \
matrix; \ i . e . \)\(,\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", 
              "      ", \( (*\ 
                uncorrelated\ disturbances\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\n", "   ", \(Psi = Table[0, {Ny}, {Ny}]\), ";",
               "\n", "        ", \(For[\ \ \ i = 1, \ 
                i\  \[LessEqual] 
                  Ny, \ \(i++\), \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \(Psi[\([i, i]\)] = 
                    1 - \ Psitemp[\([i]\)\ ]\ ;\)\[IndentingNewLine]\ \ \ \ \ \
\ \ \ ]\), ";", "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(End : \ 
                    Derive\ elements\ of\ PSI~~~~~~~~~~~~~~~~~~~~~~~~~~~\)\
*) \), "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              "  ", \(YYcor = 
                IBinv . \ \((Gmat . \ Phi\  . Transpose[Gmat] + Psi)\)\  . \ 
                  Transpose[IBinv]\), " ", ";", "\n", 
              "      ", \(XYcor = \ 
                Phi\  . \ Transpose[Gmat]\  . \ Transpose[IBinv]\), " ", ";", 
              "\n", "\[IndentingNewLine]", 
              "     ", \(SigmaHat = IdentityMatrix[Ntot]\), ";", "\n", 
              "     ", \(SigmaHat[\([xxrows, xxrows]\)] = Phi\), " ", ";", 
              "\n", "     ", \(SigmaHat[\([\ xyrows, xxrows]\)] = 
                Transpose[XYcor]\), " ", ";", "\n", 
              "     ", \(SigmaHat[\([xxrows, xyrows]\)] = XYcor\), ";", "\n", 
              "     ", \(SigmaHat[\([xyrows, xyrows]\)] = YYcor\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              " ", \( (*\ 
                Create\ a\ list\ to\ hold\ Npath\ polynomial\ equations\ \
*) \), "\[IndentingNewLine]", 
              "     ", \(polynomial = Table[0, {Npaths}, {1}]\), ";", " ", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "    ", \( (*\ 
                this\ will\ set\ up\ the\ polynomial\ equations\ to\ feed\ to\
\ solve\ *) \), "\n", 
              "     ", \(For[i = 1, \ 
                i \[LessEqual] 
                  Npaths, \ \(i++\), \[IndentingNewLine]\ \
\(polynomial[\([i]\)] = 
                    SigmaHat[\([\ \ \(cors[\([i]\)]\)[\([1]\)], \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \(cors[\([i]\)]\)[\([2]\)]\ \ \
]\)] == Smat[\([\ \ \(cors[\([i]\)]\)[\([1]\)], \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(cors[\([i]\)]\
\)[\([2]\)]\ \ ]\)];\)\n\ \ \ \ \ ]\), ";", "\n", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              "    ", \(PathCoef = Solve[\ \ polynomial, \ coefficients]\), 
              ";", "\[IndentingNewLine]", \(tempPath = PathCoef\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", \( (*\ \ Begin : \ 
                  Did\ Solve\ find\ a\ legitimate\ \(\(solution\)\(?\)\)\ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", \(If[\ 
                Length[Flatten[PathCoef]]\  \[NotEqual] 
                  Npaths\ , \ \[IndentingNewLine]\ \ \ \ \ nSolutions = 
                  Length[PathCoef]; \[IndentingNewLine]\ \ \ For[i = 1, \ 
                  i \[LessEqual] 
                    nSolutions, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \
nBadPath = 0; \[IndentingNewLine]\ \ \ \ \ \ \ For[j = 1, 
                    j \[LessEqual] 
                      Npaths, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \
\ \ \(If[\ \ \(\(PathCoef[\([i]\)]\)[\([j]\)]\)[\([2]\)]\ ^2\  > \ 
                          1, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \
nBadPath = nBadPath + 
                            1\[IndentingNewLine]\ \ \ \ \ \ \ ];\)\ \
\[IndentingNewLine]\ \ \ \ \ ]; \[IndentingNewLine]\ \ \ \ \ \ \ If[
                    nBadPath \[Equal] 
                      0, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
tempPath = PathCoef[\([i]\)]; \ 
                    Goto\ [nextStep];\[IndentingNewLine]\ \ \ \ \ ];\
\[IndentingNewLine]\ \ \ ];\[IndentingNewLine]\ ]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              " ", \(Label[nextStep]\), ";", "\[IndentingNewLine]", 
              " ", \(PathCoef =. \), ";", " ", "\[IndentingNewLine]", 
              " ", \(PathCoef = Sort[Flatten[tempPath]]\), ";", " ", 
              "\[IndentingNewLine]", " ", \(tempPath =. \), ";", " ", 
              "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              " ", \( (*\ \ End : \ 
                  Did\ Solve\ find\ a\ legitimate\ \(\(solution\)\(?\)\)\ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", \( (*\ 
                Use\ the\ replacement\ operator\  /. \ 
                  to\ replace\ results\ from\ Solve\ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\ in\ SigmaHat, \ 
                then\ convert\ to\ a\ matrix\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ *) \), 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", " ", \(SigmaHatBackup = SigmaHat\), ";", 
              "\n", "     ", \(SigmaHat = SigmaHat\  /. \ PathCoef\), " ", 
              ";", "\n", 
              "     ", \(SigmaHat = Partition[Flatten[SigmaHat], Ntot]\), ";",
               "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", \( (*\(\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(\ \ \ \ \ \ \ \ \ \)\(Calculate\)\)\ Model\ fit\ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ ~~~~~~~~~~~*) \), 
              "\[IndentingNewLine]", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), 
              "\[IndentingNewLine]", " ", \(BmatFIT = Bmat\), ";", 
              "  ", \( (*\ use\ this\ while\ calculating\ fit\ index\ *) \), 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              " ", \(fitindex = 0\), ";", "\[IndentingNewLine]", 
              " ", \(For[i = 1, 
                i \[LessEqual] 
                  Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \(For[j = 1, 
                    j \[LessEqual] 
                      Ny, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \(If[
                        BmatFIT[\([i, j]\)] \[Equal] 
                            0\  && \ \ BmatFIT[\([j, i]\)] \[Equal] 0\  && \ 
                          i \[NotEqual] 
                            j\ , \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \
fitindex = fitindex + \((SigmaHat[\([i, j]\)] - 
                                  Smat[\([i, 
                                      j]\)])\)^2; \[IndentingNewLine]\ \ \ \ \
\ \ \ \ BmatFIT[\([i, j]\)] = 
                          BmatFIT[\([j, i]\)] \[Equal] 
                            99;\[IndentingNewLine]\ \ \ ];\)\
\[IndentingNewLine]\ ];\)\[IndentingNewLine]\ ]\), ";", "\[IndentingNewLine]",
               "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              " ", \(For[i = 1, 
                i \[LessEqual] 
                  Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \(For[j = 1, 
                    j <= Nx, \(j++\), \[IndentingNewLine]\(If[
                        Gmat[\([i, j]\)] \[Equal] 0\  && \ 
                          GinModel[\([j]\)] \[Equal] 
                            1, \[IndentingNewLine]\ \ \ \(fitindex = 
                            fitindex + \((SigmaHat[\([i, \((j + Ny)\)]\)] - 
                                    Smat[\([i, \((j + 
                                        Ny)\)]\)])\)^2;\)\[IndentingNewLine]];\
\)\[IndentingNewLine]];\)\[IndentingNewLine]\ ]\), ";", "\[IndentingNewLine]",
               "\[IndentingNewLine]", "    ", "\[IndentingNewLine]", 
              " ", \(Clear[i]\), ";", "\[IndentingNewLine]", 
              " ", \(Nx = \ Sum[{GinModel[\([i]\)]}, {i, Nx}]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ How\ many\ actual\ X' s\ in\ \ model\ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  make\ Nx\ numeric\ if\ a\ List\ is\ returned*) \),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["\[IndentingNewLine]",
                FontColor->RGBColor[1, 0, 
                0]], \(If[\((ListQ[Nx] \[Equal] 
                    True)\), \[IndentingNewLine]\ \ \ \ \(Nx = \(Part[
                        Nx]\)[\([1]\)];\)\[IndentingNewLine]]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              " ", \(Ntot = Ny + Nx\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\n", 
              " ", \( (*\ 
                We\ subtract\ Npaths\ from\ ' 
                  denominator'\ because\ the\ Npath\ r' s\ are\ *) \), 
              "\[IndentingNewLine]", 
              "     ", \( (*used\ to\ solve\ the\ polynomials\ and\ are\ \
perfectly\ reproduced\ \ \ \ \ \ \ \ *) \), "\[IndentingNewLine]", 
              " ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\n", 
              " ", \(denominator = \((Ntot*\((Ntot - 1)\)/2)\)\  - \ 
                  Nx*\((Nx - 1)\)/2\  - \ Npaths\), ";", 
              "\[IndentingNewLine]", 
              " ", \( (*\(denominator = \((Ntot*\((Ntot - 1)\)/2)\)\  - \ 
                      Nx*\((Nx - 1)\)/2\ ;\)*) \), "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*CVr\  = \ #\ of\ corrs\ used\ to\ \
test\ model*) \), " ", "\[IndentingNewLine]", \(CVr = denominator\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              " ", \(If[
                fitindex\ \  \[NotEqual] 
                  0, \[IndentingNewLine]\ \ \ \ \ \ \(fitindex = 
                    Sqrt[fitindex/denominator];\)\[IndentingNewLine]\ ]\), 
              ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "    ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "  ", \( (*\ 
                return\ values\ from\ function\ call\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), "\[IndentingNewLine]", 
              "  ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
              "  ", \(If[
                Length[PathCoef] \[Equal] 
                  0, \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
SigmaHat = "\<NO SOLUTION FOUND\>"; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ PathCoef =. ; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ fitindex =. ;]\), ";", " ", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              "  ", \({\ MatrixForm[SigmaHat], corList, 
                MatrixForm[polynomial], \n\ \ \ \ \ \ \ \ \ PathCoef, \ 
                fitindex, MatrixForm[Smat], 
                MatrixForm[\ Bmat], \[IndentingNewLine]\ MatrixForm[\ Gmat], 
                Ny, Nx, \ Bmat, \ Gmat, \ Smat, \ CVr}\)}]}], 
          "\[IndentingNewLine]", "  ", "]"}]}]}]], "Input",
  FontSize->9],

Cell["  End FUNCTION:  fitModel", "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\n FUNCTION:  ",
  StyleBox["findPaths[beta,gamma]\n ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Lists all paths that are implied by the matrix representation of \
a model AND all paths that are not implied by the model. \nThe first  set is \
called the model paths. The second set is called the alternative paths.  When \
considered jointly, this \n information can be used to create a set of  \
alternative models for a given theoretical model.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(findPaths[bmat2_, 
        gmat2_] := \[IndentingNewLine]Module[{\ alternativePaths, \ 
          modelPaths}, \[IndentingNewLine]\[IndentingNewLine]\ 
        alternativePaths = \(modelPaths = {{M, 99, 
                99}}\); \[IndentingNewLine]\[IndentingNewLine]p = \
\(Dimensions[bmat2]\)[\([1]\)]; \[IndentingNewLine]q = \(Dimensions[
              gmat2]\)[\([2]\)]; \[IndentingNewLine]\ \ \ \ \ \ \ \ nb = 
          p; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ng = 
          p*q; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ For[i = \ 1, \ 
          i \[LessEqual] 
            nb, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(For[j = 1, \ 
              j \[LessEqual] 
                nb, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ If[
                NumericQ[bmat2[\([i, j]\)]]\  && \ 
                  i \[NotEqual] 
                    j, \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(alternativePaths = 
                    Append[{alternativePaths}, {"\<beta\>", i, 
                        j}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ If[\(! NumericQ[
                    bmat2[\([i, 
                        j]\)]]\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \(modelPaths = 
                    Append[{modelPaths}, {"\<beta\>", i, 
                        j}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ ];\
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \ \ \ \
]; \n\ \ \ \ \ \ \ \ \ \ \ \ For[i = \ 1, \ 
          i \[LessEqual] 
            p, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \(For[
              j = 1, \ j \[LessEqual] 
                q, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ If[NumericQ[gmat2[\([i, 
                      j]\)]], \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ alternativePaths = 
                  Append[{alternativePaths}, {"\<gamma\>", i, 
                      j}]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ ]; \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ If[\(! NumericQ[
                    gmat2[\([i, 
                        j]\)]]\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(modelPaths = 
                    Append[{modelPaths}, {"\<gamma\>", i, 
                        j}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ ];\ \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \ \ \ ]; \
\[IndentingNewLine]alternativePaths = 
          Delete[Partition[Flatten[alternativePaths], 3], 
            1]; \[IndentingNewLine]modelPaths = 
          Delete[Partition[Flatten[modelPaths], 3], 
            1]; \[IndentingNewLine]{modelPaths, 
          alternativePaths}\[IndentingNewLine]]\)], "Input",
  FontSize->9],

Cell[TextData[{
  " FUNCTION:   ",
  StyleBox["generateModel[beta, gamma,modelPaths,alternativePaths]\n ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Takes models paths and alternative paths as input and outputs a \
set of alternative models in matrix form (i.e., alternative\n forms of beta \
and gamma). ",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(generateModel[beta_, gamma_, modelPaths_, 
            alternativePaths_]\), ":=", "\[IndentingNewLine]", "   ", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({betaNew, gammaNew, betagamma, \ nb}\), ",", 
              "\[IndentingNewLine]", "       ", 
              
              RowBox[{\(betaOrig = beta\), ";", "\[IndentingNewLine]", 
                "       ", \(gammaOrig = gamma\), ";", "\[IndentingNewLine]", 
                "       ", \(betagamma = {{9, 9}}\), ";", 
                "\[IndentingNewLine]", "     ", 
                "\[IndentingNewLine]", \(nm = Length[modelPaths]\), ";", 
                "\[IndentingNewLine]", \(na = Length[alternativePaths]\), ";",
                 "\[IndentingNewLine]", 
                RowBox[{"For", "[", 
                  
                  RowBox[{\(iterM = 1\), ",", " ", \(iterM \[LessEqual] nm\), 
                    ",", " ", \(iterM++\), ",", 
                    StyleBox[" ",
                      FontColor->GrayLevel[
                      0]], \( (*\(\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(\ \
\)\(loop\)\)\ over\ model\ paths\ ~~~~~~*) \), "\[IndentingNewLine]", 
                    "         ", \(betaNew = 
                      betaOrig; \ \ \ \ \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \
\ \ gammaNew = 
                      gammaOrig; \n\n\ \ \ \ \ \ \ \  \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \[IndentingNewLine] (*\ 
                      find\ an\ existing\ path\ delete\ to\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \n\ \ \ \ \ \ \ \  (*\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)*) \[IndentingNewLine]\ \ \ \ \ \ If[\(modelPaths[\([iterM]\)]\
\)[\([1]\)] \[Equal] "\<beta\>", \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\(betaNew[\([\ \ \(modelPaths[\([iterM]\)]\)[\([2]\)], \(modelPaths[\([iterM]\
\)]\)[\([3]\)]\ ]\)] = 0;\)\[IndentingNewLine]\ \ \ ]\[IndentingNewLine]
                    \ \ \ If[\(modelPaths[\([iterM]\)]\)[\([1]\)] \[Equal] \
"\<gamma\>", \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \(gammaNew[\([\ \ \
\(modelPaths[\([iterM]\)]\)[\([2]\)], \(modelPaths[\([iterM]\)]\)[\([3]\)]\ ]\
\)] = 0;\)\[IndentingNewLine]\ ]\[IndentingNewLine]
                    \ \ \ \ \ \ \ \ \ \ \ \(For[iterA = 1, \ 
                        iterA \[LessEqual] 
                          na, \ \(iterA++\), \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*\ \(\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(\ \)\(loop\)\)\ over\ alternative\ \
paths\ ~~~~~~~*) \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
If[\(alternativePaths[\([iterA]\)]\)[\([1]\)] \[Equal] "\<beta\>", \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ betaNew[\([\ \ \
\(alternativePaths[\([iterA]\)]\)[\([2]\)], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(alternativePaths[\([iterA]\)]\)[\([3]\)]\
\ ]\)] = w; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
betagamma = Join[betagamma, {\ {betaNew, 
                                  gammaNew}}]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ betaNew[\([\ \ \
\(alternativePaths[\([iterA]\)]\)[\([2]\)], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(alternativePaths[\([iterA]\)]\)[\([\
3]\)]\ ]\)] = 
                            0;\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
If[\(alternativePaths[\([iterA]\)]\)[\([1]\)] \[Equal] "\<gamma\>", \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ gammaNew[\([\ \ \
\(alternativePaths[\([iterA]\)]\)[\([2]\)], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(alternativePaths[\([iterA]\)]\)[\(\
[3]\)]\ ]\)] = 
                            w; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ betagamma = Join[
                              betagamma, {\ {betaNew, 
                                  gammaNew}}]; \[IndentingNewLine]\ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ gammaNew[\([\ \ \
\(alternativePaths[\([iterA]\)]\)[\([2]\)], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(alternativePaths[\([iterA]\)]\)[\([\
3]\)]\ ]\)] = 
                            0;\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
];\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[IndentingNewLine]\ \ \ \
\ \ \ \ \ \ \ ];\)\)}], "\[IndentingNewLine]", " ", "]"}], ";", "     ", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                " ", \(bg = Rest[betagamma]\), ";", "\[IndentingNewLine]", 
                " ", \(Clear[betagamma]\), ";", "\[IndentingNewLine]", 
                " ", \(betagamma = bg\), ";", "\[IndentingNewLine]", 
                " ", \(Clear[bg]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                " ", \(lb = Length[betagamma]\), ";", "\[IndentingNewLine]", 
                "\n", "      ", \( (*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \), \( (*\ 
                  Now\ check\ for\ Model\ Identification\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \), "\n", 
                "     ", \( \
(*\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)*) \), "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(Imat = 
                  IdentityMatrix[\ \ \ Length[\ \
\(betagamma[\([1]\)]\)[\([1]\)]]\ \ \ \ ]\), ";", 
                "\[IndentingNewLine]", \(position = {0}\), ";", 
                "\[IndentingNewLine]", \(For[k = 1, \ 
                  k \[LessEqual] 
                    lb, \ \(k++\), \[IndentingNewLine]\ \ IminusBeta = 
                    Imat\  - \ \ \(betagamma[\([k]\)]\)[\([1]\)]\ \ ; \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ If[\ \ Det[IminusBeta]\ \  == \ 
                      1, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(position = Append[position, 
                          k];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
];\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \[IndentingNewLine]]\), ";", 
                "\[IndentingNewLine]", \(position = Rest[position]\), ";", 
                "\[IndentingNewLine]", \(betagamma = 
                  betagamma[\([position]\)]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \({betagamma}\)}]}], 
            "\[IndentingNewLine]", "]"}]}], ";"}], 
      "\[IndentingNewLine]"}]], "Input",
  FontSize->9],

Cell[TextData[{
  " Function:",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["whichCors",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n Function to choose a set of observed correlations for the system of \
polynomial equations."
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\(\ \)\(\(whichCors[beta_, 
        gamma_] := \[IndentingNewLine]Module[{corList}, \n\ \ \ \ \ betaPaths \
= \(gammaPaths = {{M, 99, 99}}\); \[IndentingNewLine]corList = {{99, 
              99}}; \[IndentingNewLine]i =. ; \[IndentingNewLine]j =. ; \
\[IndentingNewLine]nb = \(Dimensions[
              beta]\)[\([1]\)]; \[IndentingNewLine]ng = \(Dimensions[
              gamma]\)[\([2]\)]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ For[
          i = \ 1, \ 
          i \[LessEqual] 
            nb, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(For[j = 1, \ 
              j \[LessEqual] 
                nb, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \(If[\(! NumericQ[
                      beta[\([i, 
                          j]\)]]\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(betaPaths = 
                      Append[{betaPaths}, {"\<beta\>", i, 
                          j}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ ];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \
\ \ \ \ \ ]; \ \[IndentingNewLine]\n\ \ \ \ \ \ \ \ \ \ \ For[i = \ 1, \ 
          i \[LessEqual] 
            nb, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(For[j = 1, \ 
              j \[LessEqual] 
                ng, \ \(j++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \(If[\(! NumericQ[
                      gamma[\([i, 
                          j]\)]]\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \(gammaPaths = 
                      Append[{gammaPaths}, {"\<gamma\>", i, 
                          j}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ ];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ ];\)\[IndentingNewLine]\ \ \
\ \ \ \ \ ]; \ \ \ \ \ \ \[IndentingNewLine]\ 
        betaPaths = 
          Delete[Partition[Flatten[betaPaths], 3], 1]; \[IndentingNewLine]\ 
        gammaPaths = 
          Delete[Partition[Flatten[gammaPaths], 3], 
            1]; \[IndentingNewLine]\[IndentingNewLine]\ 
        blength = Length[betaPaths]; \[IndentingNewLine]\ 
        glength = Length[gammaPaths]; \[IndentingNewLine]\ \n\ \ \ \ For[
          i\  = \ 1, 
          i \[LessEqual] 
            blength, \ \(i++\), \[IndentingNewLine]\ \ \ \(corList = 
              Append[{corList}, {\(betaPaths[\([i]\)]\)[\([2]\)], \n\ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(betaPaths[\([i]\)]\)[\([3]\)\
]}];\)\[IndentingNewLine]]; \[IndentingNewLine]\ \ \ \ \ \ For[i = 1, \ 
          i \[LessEqual] 
            glength, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(corList = 
              Append[{corList}, {\(gammaPaths[\([i]\)]\)[\([2]\)], \
\(gammaPaths[\([i]\)]\)[\([3]\)] + 
                    nb}];\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ ]; \
\[IndentingNewLine]\ 
        corList = 
          Delete[Partition[Flatten[corList], 2], 
            1]; \[IndentingNewLine]\[IndentingNewLine]corList\
\[IndentingNewLine]\ ]\)\(\[IndentingNewLine]\)
    \)\)\)], "Input",
  FontSize->9],

Cell[TextData[{
  "  FUNCTION ",
  StyleBox["checkMatrices",
    FontColor->RGBColor[0, 0, 1]],
  "  \ncheck to see if a previously classified  endogenous variable has \
become an exogenous variable in an alternate model and modify matrices beta \
and gamma accordingly\n This function works as follows:  A previously defined \
endogenous variable may become exogenous by the delete 1 add 1 rule.  This \
can  be spotted by determining whether the corresponding rows in Beta and \
Gamma contain all zeros. "
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(checkMatrices[betaA_, gammaA_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({betaC, gammaC, takeColumn, i, iter, \ Ny, \ Nx, \ 
                brows, \ bcols, \ gcols, \ betaB, \ gammaB}\), ",", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
              
              RowBox[{\(Ny = \(Dimensions[betaA]\)[\([1]\)]\), ";", 
                "\[IndentingNewLine]", 
                "  ", \(Nx = \(Dimensions[gammaA]\)[\([2]\)]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                " ", \(brows = \(bcols = Range[1, Ny]\)\), ";", 
                "\[IndentingNewLine]", " ", \(gcols = Range[1, Nx]\), ";", 
                "\n", "\[IndentingNewLine]", "\n", 
                "     ", \(takeColumn = 99\), ";", 
                "\[IndentingNewLine]", \(For[iter = 1, 
                  iter \[LessEqual] 
                    Ny, \(iter++\), \[IndentingNewLine]\ \(If[
                      NumberQ[
                          Sum[\ \ \ \(betaA[\([iter]\)]\)[\([i]\)], {i, 
                              Ny}\ \ ]]\  && \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ NumberQ[Sum[\ \ \ \(gammaA[\([iter]\)]\)[\([i]\)], {i, 
                              Nx}\ \ ]], \[IndentingNewLine]\ \ brows = 
                        Delete[
                          brows, {iter}]; \[IndentingNewLine]takeColumn = 
                        iter; \n\ \ \ \ \ \ \ \ \ \ \ \ \ iter = 
                        Ny + 1;\[IndentingNewLine]];\)\[IndentingNewLine]]\), 
                ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(If[
                  takeColumn \[NotEqual] 
                    99, \n (*\ \ delete\ the\ appropriate\ row\ in\ beta\ and\
\ gamma\ \ *) \[IndentingNewLine]\ \ betaB = 
                    betaA[\([brows, 
                        bcols]\)]; \[IndentingNewLine]\ \ gammaB = 
                    gammaA[\([brows, 
                        gcols]\)]; \[IndentingNewLine] (*\ \ \ \ increase\ \
gamma\ by\ one\ column\ \ \ \ \ *) \n\ \ \ \ \ \ gammaC = 
                    Table[g[i, j], {i, 1, Ny - 1}, {j, 1, 
                        Nx + 1}]; \n\ \ \ \ \ \ gammaC[\([Range[1, Ny - 1], 
                        Range[1, Nx]]\)] = 
                    gammaB; \n\ \ \ \ \ \ gammaC[\([Range[1, Ny - 1], 
                        Nx + 1]\)] = 
                    betaB[\([Range[1, Ny - 1], 
                        takeColumn]\)]; \n\ \ \n\ \ \ \ \ \ betaC = 
                    Table[b[i, j], {i, 1, Ny - 1}, {j, 1, 
                        Ny - 1}]; \n\[IndentingNewLine]For[i = 1, 
                    i \[LessEqual] 
                      Length[brows], \(i++\), \[IndentingNewLine]\ \
\(betaC[\([Range[1, Ny - 1], i\ ]\)] = 
                        betaB[\([Range[1, Ny - 1], 
                            brows[\([i]\)]\ ]\)];\)\[IndentingNewLine]];\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]]\), ";", " ", 
                StyleBox[\( (*End\ of\ If[takeColumn \[NotEqual] 99]\ *) \),
                  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(If[
                  takeColumn \[Equal] 99, \[IndentingNewLine]betaC = 
                    betaA; \[IndentingNewLine]gammaC = 
                    gammaA;\[IndentingNewLine]]\), ";", "\[IndentingNewLine]",
                 "\[IndentingNewLine]", 
                "  ", \({betaC, gammaC, takeColumn}\)}]}], 
            "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}]], "Input",
  FontSize->9],

Cell[TextData[{
  "FUNCTION:",
  StyleBox[" allPaths[allModelsIN,sigmaList]",
    FontColor->RGBColor[0, 0, 1]],
  "\nThis function generates results for the defined set of alternative \
models\nIt checks to see if model contains paths that violate design \
constraints (i.e., time ordering)"
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{
      RowBox[{\(allPaths[allModelsIN_, sigmaList_, \ DegreeFreedom_]\), ":=", 
        "\n", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({results, iter, \ altB, \ altG, \ i}\), ",", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(results = {}\), ";", 
              "\[IndentingNewLine]", \(numberOfModels = \ \(Dimensions[
                    allModelsIN[\([1]\)]]\)[\([1]\)]\), ";", "\n", 
              "    ", \(numModels = numberOfModels\), ";", "\n", 
              "    ", \(rows = Range[Ntot]\), ";", "\[IndentingNewLine]", 
              "\n", \( (*take\ first\ column\ of\ sigma*) \), "\n", 
              "    ", \(col1 = sigma[\([rows, 1]\)]\), ";", "\n", "\n", 
              
              StyleBox[\( (*\ \
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\
\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\
\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)\(~\)*) \),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["\n",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\( (*this\ loops\ over\ all\ alternative\ models*) \),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], "\n", 
              RowBox[{"For", "[", 
                
                RowBox[{\(iter = 1\), ",", \(iter \[LessEqual] numModels\), 
                  ",", \(iter++\), ",", " ", "\[IndentingNewLine]", 
                  "          ", 
                  
                  RowBox[{\(altB = \ \ \(\(allModelsIN[\([1]\)]\)[\([iter]\)]\
\)[\([1]\)]\), " ", ";", "\[IndentingNewLine]", 
                    "          ", \(altG = \ \ \
\(\(allModelsIN[\([1]\)]\)[\([iter]\)]\)[\([2]\)]\), " ", ";", 
                    "\[IndentingNewLine]", "          ", 
                    RowBox[{"corList", "=", 
                      RowBox[{
                        StyleBox["whichCors",
                          FontColor->RGBColor[0, 0, 1]], "[", \(altB, altG\), 
                        "]"}]}], ";", "\n", 
                    "                ", \(forbidPaths = badPaths\), ";", "\n",
                     "\n", 
                    
                    StyleBox[\( (*do\ the\ badPaths\ need\ to\ be\ \
\(\(renumbered\)\(?\)\)*) \),
                      FontColor->RGBColor[1, 0, 0]], "\n", "      ", 
                    RowBox[{"If", "[", 
                      
                      RowBox[{\(Length[timeOrder] > 0\), ",", "         ", 
                        "\n", "           ", 
                        
                        RowBox[{\(col2 = \(sigmaList[\([iter]\)]\)[\([rows, 
                                1]\)]\), ";", "\n", 
                          "          ", \( (*determine\ if\ matrix\ has\ been\
\ shuffled*) \), "\n", "           ", \(movedvar = 0\), ";", "\n", 
                          "           ", \(For[i = 1, 
                            i \[LessEqual] 
                              Ntot, \(i++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(If[col1[\([i]\)] \[NotEqual] 
                                  col2[\([i]\)], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ movedvar = 
                                  i; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ i = 
                                  Ntot;\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
];\)\n\ \ \ \ \ \ \ \ \ \ \ \ \ ]\), ";", "\n", "         ", 
                          
                          StyleBox[\( (*if\ the\ matrix\ was\ shuffled\ \
because\ an\ endogenous\ variable*) \),
                            FontColor->RGBColor[1, 0, 0]], 
                          StyleBox["\n",
                            FontColor->RGBColor[1, 0, 0]], 
                          
                          StyleBox[\( (*became\ exogenous, \ 
                              then\ the\ identifiers\ in\ badPaths\ must\ \ *) \
\),
                            FontColor->RGBColor[1, 0, 0]], 
                          StyleBox["\n",
                            FontColor->RGBColor[1, 0, 0]], 
                          
                          StyleBox[\( (*\ 
                              also\ be\ shuffled\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \),
                            FontColor->RGBColor[1, 0, 0]], "\n", 
                          "          ", \(If[
                            movedvar \[NotEqual] 
                              0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(For[
                                i = 1, 
                                i \[LessEqual] 
                                  Ntot, \(i++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ if\ any\ #\  = \ mv, \ 
                                  multiply\ by\  - 
                                    1\ *) \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ If[forbidPaths[\([i, 1]\)] \[Equal] 
                                    movedvar, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ forbidPaths[\([i, 1]\)] = \ 
                                    forbidPaths[\([i, 
                                        1]\)]*\(-1\)]; \n\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ If[forbidPaths[\([i, 2]\)] \[Equal] 
                                    movedvar, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ forbidPaths[\([i, 2]\)] = \ 
                                    forbidPaths[\([i, 
                                        2]\)]*\(-1\)]; \n\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ If[forbidPaths[\([i, 1]\)] > 
                                    movedvar, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ forbidPaths[\([i, 1]\)] = \ 
                                    forbidPaths[\([i, 1]\)] - 
                                      1]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ If[forbidPaths[\([i, 2]\)] > 
                                    movedvar, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ forbidPaths[\([i, 2]\)] = \ 
                                    forbidPaths[\([i, 2]\)] - 
                                      1]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ If[forbidPaths[\([i, 1]\)] < 
                                    0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ forbidPaths[\([i, 1]\)] = \ 
                                    Ntot]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ If[forbidPaths[\([i, 2]\)] < 
                                    0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ forbidPaths[\([i, 2]\)] = \ 
                                    Ntot];\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ ];\)\n\ \ \ \ \ \ \ \ \ \ ]\), ";"}]}], " ", "\n", "     ", "]"}], ";", 
                    "\n", "      ", \( (*does\ the\ model\ include\ any\ \
forbidden\ \(\(paths\)\(?\)\)*) \), " ", "\n", "\n", 
                    "       ", \(tmp = 
                      Length[Intersection[forbidPaths, corList]]\), ";", "\n",
                     "     ", "\n", "\n", 
                    "     ", \( (*reduce\ numberOfModels\ by\ one\ if\ \
forbidden\ path\ present*) \), "\n", 
                    "      ", \(If[
                      tmp \[GreaterEqual] 
                        1, \ \(numberOfModels = numberOfModels - 1;\)]\), ";",
                     "\n", "\[IndentingNewLine]", "\n", "      ", 
                    RowBox[{"If", "[", 
                      
                      RowBox[{\(tmp \[Equal] 0\), ",", "\[IndentingNewLine]", 
                        
                        
                        RowBox[{\(smatiter = sigmaList[\([iter]\)]\), ";", 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", 
                          RowBox[{"tmp", "=", 
                            RowBox[{
                              StyleBox["fitModel",
                                FontColor->RGBColor[0, 0, 1]], "[", \(altB, 
                              altG, smatiter, corList\), "]"}]}], " ", ";", 
                          "\[IndentingNewLine]", 
                          "\[IndentingNewLine]", \( (*\ 
                            Check\ to\ make\ sure\ alternative\ model\ has\ \
same\ DF\ as\ Dstar\ *) \), "\[IndentingNewLine]", \(altDF = tmp[\([14]\)]\), 
                          ";", "\[IndentingNewLine]", 
                          "\[IndentingNewLine]", \(If[
                            altDF == 
                              DegreeFreedom, \[IndentingNewLine]\ \(AppendTo[\
\ \ results, \ tmp];\)\[IndentingNewLine]]\), ";", "\[IndentingNewLine]", 
                          "   ", \(If[
                            altDF \[NotEqual] 
                              DegreeFreedom, \[IndentingNewLine]\ \ \ \ \ \
\(numberOfModels = numberOfModels - 1;\)\[IndentingNewLine]\ \ ]\), ";", 
                          "\[IndentingNewLine]", \(smatiter =. \), ";", 
                          " ", \(tmp =. \), ";", " ", \(forbidPaths =. \), 
                          ";", " ", \(altDF =. \), ";"}]}], "\n", 
                      "          ", "]"}], ";"}]}], "\n", "  ", "]"}], ";", 
              " ", 
              StyleBox[\( (*END\ FOR\ loop\ over\ models*) \),
                FontColor->RGBColor[1, 0, 0]], "\n", "\[IndentingNewLine]", 
              "results"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
  FontSize->9],

Cell[TextData[{
  "FUNCTION: ",
  StyleBox["printResults[solutions]",
    FontColor->RGBColor[0, 0, 1]],
  "\n"
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(printResults[vecResults_, \ 
          p_] := \[IndentingNewLine]\[IndentingNewLine]Module[{nothing}, \
\[IndentingNewLine]\[IndentingNewLine]line = 
            TF["\<\n\n\n\
=========================================================\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            TF["\<    Summary of Results for Alternate Model # \>"]; \
\[IndentingNewLine]Write[file1, line, p]; \[IndentingNewLine]CVcor = \n\ 
            TF[\ \ StringJoin["\<\n\n   Number of Available Correlations for \
Model Testing = \>", \ 
                ToString[\ \(vecResults[\([p]\)]\)[\([14]\)]]]]; \
\[IndentingNewLine]Write[file1, 
            CVcor]; \[IndentingNewLine]\[IndentingNewLine]line = 
            TF["\<\n\n\n\n[1] Root Mean Squared Residuals:\>"]; \n\ \ \ \ \ \ \
\ Write[file1, 
            line]; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]rmsr = \n\ 
            TF[\ \ StringJoin["\<\n     RMSr = \>", \ 
                ToString[
                  rnd[\ \n\ \ \ \ \ \ \ \ \
\(vecResults[\([p]\)]\)[\([5]\)]]]]]; \[IndentingNewLine]Write[file1, 
            rmsr]; \[IndentingNewLine]\[IndentingNewLine]line = 
            TF["\<\n\n\n[2] Parameter matrices\>"]; \[IndentingNewLine]Write[
            file1, line]; \[IndentingNewLine]line = 
            TF["\<\nBeta\>"]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]betaa = 
            MatrixForm[\(vecResults[\([p]\)]\)[\([7]\)]\ ]; \
\[IndentingNewLine]gammaa = 
            MatrixForm[\(vecResults[\([p]\)]\)[\([8]\)]\ ]; \
\[IndentingNewLine]line = \ \ OF[betaa]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]line = 
            TF["\<\nGamma\>"]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]line = 
            OF[\ gammaa\ ]\ \ ; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[3]  Predicted Correlation Matrix:\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            OF[PF[\ \ \(vecResults[\([p]\)]\)[\([1]\)]]]; \
\[IndentingNewLine]Write[file1, \ \ line\ \ ]; \[IndentingNewLine]Write[
            file1, blank]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[4]  Observed Correlation Matrix:\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            OF[PF[\ \(vecResults[\([p]\)]\)[\([6]\)]]]; \
\[IndentingNewLine]Write[file1, \ \ line\ \ ]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[5]  Observed r's used in solve:\n\>"]; \
\[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]line = \
\(vecResults[\([p]\)]\)[\([2]\)]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]Write[file1, 
            blank]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[6]  Model implied polynomials\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \n\ \ \ \ \ \ line = 
            OF[\ \(vecResults[\([p]\)]\)[\([3]\)]\ ]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[7]  Estimated Coefficients (i.e.,solution to \
polynomial equations):\n\>"]; \[IndentingNewLine]Write[file1, line];  (*\ 
            this\ code\ is\ used\ to\ round\ the\ coefficients\ to\ 3\ \
decimal\ places*) \[IndentingNewLine]coef = \(vecResults[\([p]\)]\)[\([4]\)]\ \
; \[IndentingNewLine]c1 = 
            Map[rnd, 
              Table[Part[Part[coef, i], 2], {i, 1, 
                  Length[coef]}]]; \[IndentingNewLine]c2 = 
            Table[Part[Part[coef, i], 1], {i, 1, 
                Length[coef]}]; \[IndentingNewLine]tempcoef = {{}}; \
\[IndentingNewLine]For[i = 1, 
            i\  \[LessEqual] 
              Length[c2], \(i++\), \ \ \[IndentingNewLine]\(tempcoef = 
                Join[tempcoef, 
                  mkCoef[c2[\([i]\)], 
                    c1[\([i]\)]\ ]\ ];\)\[IndentingNewLine]\ \ \ ]; \
\[IndentingNewLine]coef = Rest[tempcoef]; \[IndentingNewLine]line = 
            OF[coef\ ]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]Write[file1, 
            blank];\[IndentingNewLine]\[IndentingNewLine]];\)\(\
\[IndentingNewLine]\)
    \)\)\)], "Input",
  FontSize->9],

Cell[TextData[{
  "FUNCTION: ",
  StyleBox["printTheoryResults[vecResults_]",
    FontColor->RGBColor[0, 0, 1]],
  "\n"
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\(\n\)\(\(printTheoryResults[
          vecResults_] \
:= \[IndentingNewLine]\[IndentingNewLine]Module[{nothing}, \n\ \ \ \ Ny = \
\(Dimensions[beta]\)[\([1]\)]; \n\ \ \ \ Nx = \(Dimensions[
                gamma]\)[\([2]\)]; \n\ \ \ \ Ntot = 
            Nx + Ny; \n\ \ \ \ Npaths = \(Dimensions[
                coefficients = 
                  Join[\ Select[Flatten[gamma], 
                      FreeQ[#, 0] &], \[IndentingNewLine]\ 
                    Select[Flatten[beta], 
                      FreeQ[#, 
                          0] &]]]\)[\([1]\)]; \n\ \ \ \ \n\ \ \ \ \ \
nonRedundantCorrs = Ntot*\((Ntot - 1)\)/2; \n\ \ \ \ \ exogCorrs = 
            Nx*\((Nx - 1)\)/2; \n\ \ \ \ \ totalCorrsInSolve = 
            exogCorrs\  + \ Npaths; \n\ \ \ \ \ nonUsedCorrs = \ 
            nonRedundantCorrs\  - \ exogCorrs - 
              Npaths; \n\[IndentingNewLine]beta = 
            MatrixForm[beta]; \[IndentingNewLine]gamma = 
            MatrixForm[
              gamma]; \ \[IndentingNewLine]\[IndentingNewLine]line = \n
            TF["\<\n\n\n                                    VERIPATH 1.3 
\n\n\t\t\t\t  Niels G. Waller\>"]; \[IndentingNewLine]Write[file1, 
            line]; \n\[IndentingNewLine]line1a = 
            TF["\<\nAs described in: \>"]; \[IndentingNewLine]line1b = \n
            TF["\<\n Meehl, P. E. & Waller, N. G. (2001). The Path Analysis \
Controversy: \nA New Statistical Approach to Strong Appraisal of \
Verisimilitude\>"]; \[IndentingNewLine]Write[file1, line1a, 
            line1b]; \n\[IndentingNewLine]Write[file1, 
            blank]; \[IndentingNewLine]Write[file1, 
            blank]; \n\[IndentingNewLine]line = 
            TF["\<\n\n\nSummary of Results for D-star (Investigator's \
Model)\>"]; \[IndentingNewLine]Write[file1, line]\ ; \n\ \ \ \ \ \ \ Write[
            file1, blank]; \n\n\ \ \ \ \ \ \ titleLine = 
            TF[StringJoin["\<Job title: \>", 
                jobTitle]]; \n\ \ \ \ \ \ \ Write[file1, 
            titleLine]; \n\n\n\ \ \ \ \ \ \ line = 
            StringJoin["\<\n\nThe matrix contains \>", 
              ToString[nonRedundantCorrs]]; \n\ \ \ \ \ \ line = 
            TF[StringJoin[
                line, "\< nonredundant correlations.\>"]]; \n\ \ \ \ \ \ \ \
Write[file1, line]; \n\n\n\ \ \ \ \ \ \ line = 
            TF[StringJoin[
                ToString[
                  exogCorrs], \ "\< correlation(s) are among exogenous \
variables.\>"]]; \n\ \ \ \ \ \ \ Write[file1, 
            line]; \n\n\n\ \ \ \ \ \ \ line1 = 
            StringJoin[
              ToString[
                Npaths], \ "\< paths were estimated using \>"]; \n\ \ \ \ \ \ \
line2 = StringJoin[
              ToString[
                totalCorrsInSolve], \ "\< correlations in \>"]; \n\ \ \ \ \ \ \
\ line3 = TF[
              StringJoin[
                ToString[
                  Npaths], \ "\< equations.\>"]]; \n\ \ \ \ \ \ \ line = 
            TF[StringJoin[line1, line2]]; \n\ \ \ \ \ \ Write[file1, line, 
            line3]; \n\n\n\ \ \ \ \ \ line\  = \ 
            TF[\ StringJoin[
                ToString[
                  nonUsedCorrs], \ "\< correlations are available to assess \
the model's verisimilitude.\>"]]; \n\ \ \ \ \ \ \ Write[file1, 
            line]; \n\n\[IndentingNewLine]line = 
            TF["\<\n\n\n[1] Root Mean Squared Residuals:\>"]; \n\ \ \ \ \ \ \ \
Write[file1, line]; \n\n\[IndentingNewLine]rmsr = \ 
            TF[\ \ StringJoin["\<\n     RMSr = \>", \ 
                ToString[
                  rnd[\ \(vecResults[\([1]\)]\)[\([5]\)]]]]]; \
\[IndentingNewLine]Write[file1, rmsr\ ]; \n\n\[IndentingNewLine]Write[file1, 
            blank]; \[IndentingNewLine]\n
          line = TF["\<\n\n\n[2] Parameter matrices\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]\n
          line = TF["\<\nBeta\>"]; \n\ \ \ \ \ \ Write[file1, 
            line]; \[IndentingNewLine]\n
          line = \ \ OF[beta]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]\n
          line = TF["\<\nGamma\>"]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]\n
          line = OF[\ gamma\ ]\ \ ; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]\n
          line = TF["\<\n\n\n[3]  Predicted Correlation Matrix:\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            OF[PF[\ \ \(vecResults[\([1]\)]\)[\([1]\)]]]; \
\[IndentingNewLine]Write[file1, \ \ line\ \ ]; \[IndentingNewLine]Write[
            file1, blank]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[4]  Observed Correlation Matrix:\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            OF[PF[\ \(vecResults[\([1]\)]\)[\([6]\)]]]; \
\[IndentingNewLine]Write[file1, \ \ line\ \ ]; \[IndentingNewLine]line = 
            
            TF["\<\n\n\n[5]  Observed r's used in solve:\n\>"]; \
\[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]line = \
\(vecResults[\([1]\)]\)[\([2]\)]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]Write[file1, 
            blank]; \[IndentingNewLine]line = 
            TF["\<\n\n\n[6]  Model implied polynomials\n\>"]; \
\[IndentingNewLine]Write[file1, line]; \[IndentingNewLine]line = 
            OF[\ \(vecResults[\([1]\)]\)[\([3]\)]\ ]; \n\ \ \ \ \ \ \ Write[
            file1, line]; \[IndentingNewLine]\n
          line = TF["\<\n\n\n[7]  Estimated Coefficients (i.e.,solution to \
polynomial equations):\n\>"]; \[IndentingNewLine]Write[file1, 
            line]; \n\[IndentingNewLine] (*\ 
            this\ section\ of\ code\ is\ used\ to\ round\ the\ coefficients\ \
to\ 3\ decimal\ places*) \[IndentingNewLine]coef = \
\(vecResults[\([1]\)]\)[\([4]\)]\ ; \[IndentingNewLine]c1 = 
            Map[rnd, 
              Table[Part[Part[coef, i], 2], {i, 1, 
                  Length[coef]}]]; \[IndentingNewLine]c2 = 
            Table[Part[Part[coef, i], 1], {i, 1, 
                Length[coef]}]; \[IndentingNewLine]tempcoef = {{}}; \
\[IndentingNewLine]For[i = 1, 
            i\  \[LessEqual] 
              Length[c2], \(i++\), \ \ \[IndentingNewLine]\(tempcoef = 
                Join[tempcoef, 
                  mkCoef[c2[\([i]\)], 
                    c1[\([i]\)]\ ]\ ];\)\[IndentingNewLine]\ \ \ ]; \
\[IndentingNewLine]coef = Rest[tempcoef]; \[IndentingNewLine]line = 
            OF[coef\ ]; \[IndentingNewLine]Write[file1, 
            line]; \[IndentingNewLine]\n
          corBounds[sigma, Ntot, Ny, \(vecResults[\([1]\)]\)[\([2]\)]]; \n\n
          If[Length[timeOrder] > 0, \n
            line = TF["\<\n\n[10]  Forbidden Paths\n\>"]; \n
            Write[file1, line]; \nline = timeOrder; \nWrite[file1, line]; \n
            Write[file1, blank]; \n\ \ \ \ \ \ \ \ lengthbadPaths = 
              Length[badPaths]; \n\ \ \ \ \ \ \ \ For[liter = 1, 
              liter \[LessEqual] 
                lengthbadPaths, \(liter++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
line = \ Rule[badPaths[\([liter, 2]\)], 
                  badPaths[\([liter, 
                      1]\)]\ ]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Write[file1, 
                line];\n\ \ \ \ \ \ \ \ \ ];\n\ ];\[IndentingNewLine]\n];\)\(\
\ \)\( (*end\ of\ function*) \)\(\[IndentingNewLine]\)
    \)\)\)], "Input",
  FontSize->9],

Cell[TextData[{
  StyleBox["FUNCTION:  ",
    FontSize->9],
  StyleBox["printLISREL[vecResults_, p_]",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(printLISREL[vecResults_, \ p_]\), ":=", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({Ny, \ Nx, \ Ntot, dataLine1, \ dataLine2, \ lisBeta, \ 
                lisGamma, lisGammaDimensions, tmpGamma, \ gammaSum, \ 
                lisSigma, nVar, nVarMinusOne, lisSD}\), ",", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              RowBox[{\(l1 = "\<TI  Alternative Model: \>"\), ";", 
                "\[IndentingNewLine]", \(modelNum = ToString[p]\), ";", 
                "\[IndentingNewLine]", \(line = 
                  TF[StringJoin[\ l1, modelNum]]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, line]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(Ny = \ \ \
\(vecResults[\([p]\)]\)[\([9]\)]\), ";", 
                "\[IndentingNewLine]", \(Nx = \ \ \
\(vecResults[\([p]\)]\)[\([10]\)]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(lisBeta = \
\(vecResults[\([p]\)]\)[\([11]\)]\), " ", ";", 
                "\[IndentingNewLine]", \(lisGamma = \
\(vecResults[\([p]\)]\)[\([12]\)]\), ";", 
                "\[IndentingNewLine]", \(lisSigma = \
\(vecResults[\([p]\)]\)[\([13]\)]\), ";", 
                "\[IndentingNewLine]", \(lisSD = stdArray[\([p]\)]\), ";", 
                "\[IndentingNewLine]", \(lisGammaDimensions = \(Dimensions[
                      lisGamma]\)[\([2]\)]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(nVar\  = \ \(Dimensions[
                      sigma]\)[\([1]\)]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                
                StyleBox[\( (*Make\ pattern\ matrices\ for\ GA\ and\ BE\ *) \
\),
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[";",
                  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                "  ", \(For[i\  = \ 1, \ 
                  i \[LessEqual] 
                    Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \ \ \ \(For[
                      j = 1, \ 
                      j \[LessEqual] 
                        lisGammaDimensions, \ \(j++\), \[IndentingNewLine]\ \ \
\ \ \ \ \ \ \(If[\ \(! NumericQ[\ \ lisGamma[\([i, 
                                  
                                  j]\)]\ \ ]\), \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \ lisGamma[\([i, j]\)] = 
                            1\[IndentingNewLine]\ \ \ ];\)\[IndentingNewLine]\
\ \ ];\)\[IndentingNewLine]\ ]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                
                StyleBox[\( (*\ 
                    Make\ Gamma\ and\ Sigma\ appropriate\ sizes\ if\ an\ \
exogenous\ *) \),
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[\( (*var\ drops\ out\ of\ model\ *) \),
                  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(gammaColMissing = 0\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(For[iter1 = 1, 
                  iter1 \[LessEqual] 
                    lisGammaDimensions, \(iter1++\), \[IndentingNewLine]\ \ \
tmpGamma = Column[\ lisGamma, iter1]; \[IndentingNewLine]\ \ gammaSum = 
                    tmpGamma . tmpGamma; \[IndentingNewLine]\ 
                  If[gammaSum \[Equal] 0, 
                    gammaColMissing = iter1];\[IndentingNewLine]]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{"If", "[", " ", "\[IndentingNewLine]", 
                  RowBox[{\((gammaColMissing\  > 0)\), ",", "       ", 
                    StyleBox[\( (*IF : \ a\ col\ of\ Gamma\ is\ all\ 0'*) \),
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(", 
                      
                      RowBox[{\(lisGamma = 
                          lisGamma[\([Range[1, Ny], 
                              Drop[Range[1, 
                                  lisGammaDimensions], {gammaColMissing}]\ \
]\)]\), ";", "  ", 
                        
                        StyleBox[\( (*THEN : \ 
                              fix\ gamma, \ \(sigma\  &\)\ sd*) \),
                          FontColor->RGBColor[1, 0, 0]], 
                        "\[IndentingNewLine]", \(rows = 
                          Drop[Range[1, 
                              nVar], {nVar - lisGammaDimensions + 
                                gammaColMissing}]\), ";", 
                        "\[IndentingNewLine]", \(lisSigma = 
                          MatrixForm[lisSigma[\([rows, rows]\)]]\), ";", 
                        "\[IndentingNewLine]", \(lisSD = {\(lisSD[\([1]\)]\)[\
\([rows]\)]}\), ";"}], "\[IndentingNewLine]", ")"}], ","}], 
                  "\[IndentingNewLine]", " ", "\[IndentingNewLine]", " ", 
                  "]"}], ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(For[i\  = \ 1, \ 
                  i \[LessEqual] 
                    Ny, \ \(i++\), \[IndentingNewLine]\ \ \ \(For[j = 1, \ 
                      j \[LessEqual] 
                        Ny, \ \(j++\), \[IndentingNewLine]\ \ \ \(If[\ \(! \
NumericQ[\ \ lisBeta[\([i, 
                                  j]\)]\ \ ]\), \[IndentingNewLine]\ \ \ \ \ \
\ lisBeta[\([i, j]\)] = 
                            1\[IndentingNewLine]];\)\[IndentingNewLine]];\)\
\[IndentingNewLine]]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(Nxstr = ToString[Nx]\), ";", 
                "\[IndentingNewLine]", \(Nxstr = 
                  StringJoin["\< NX=\>", Nxstr]\), ";", 
                "\[IndentingNewLine]", \(Nystr = ToString[Ny]\), ";", 
                "\[IndentingNewLine]", \(Nystr = 
                  StringJoin["\< NY=\>", Nystr]\), ";", 
                "\[IndentingNewLine]", \(Ntot = Nx + Ny\), ";", 
                "\[IndentingNewLine]", \(Ntotstr = ToString[Ntot]\), ";", 
                "\[IndentingNewLine]", \(dastr1 = "\<DA  NI =\>"\), ";", 
                "\[IndentingNewLine]", \(daLine1 = \ \ \ StringJoin[dastr1, \ 
                    Ntotstr\ ]\), " ", ";", 
                "\[IndentingNewLine]", \(nSubjstr = ToString[nSubj]\), ";", 
                "\[IndentingNewLine]", \(daLine1a = "\< NO = \>"\), ";", 
                "\[IndentingNewLine]", \(daLine1b\  = \ 
                  StringJoin[daLine1a, \ nSubjstr]\), ";", 
                "\[IndentingNewLine]", \(daLine1c = 
                  StringJoin[daLine1, daLine1b]\), ";", 
                "\[IndentingNewLine]", \(daLine2 = "\< NG = 1 MA = CM\>"\), 
                ";", " ", 
                "\[IndentingNewLine]", \(daLine\  = \ 
                  TF[\ StringJoin[daLine1c, \ daLine2]\ ]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, daLine]\), ";", 
                "\[IndentingNewLine]", \(KM = TF["\<KM FU\>"]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, \ KM]\), ";", 
                "\[IndentingNewLine]", \(line = 
                  OF[PF[MatrixForm[\ lisSigma]]]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, \ \ line\ \ ]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ \ now\ write\ SD\ line\ \ *) \),
                 "\[IndentingNewLine]", \(line = TF["\<SD\>"]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, line]\), ";", 
                "\[IndentingNewLine]", \(line = TF["\<*\>"]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, line]\), ";", 
                "\[IndentingNewLine]", \(line = OF[PF[MatrixForm[lisSD]]]\), 
                ";", "\[IndentingNewLine]", \(Write[file2, line]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ \ now\ write\ MO\ line\ \ *) \),
                 ";", "\[IndentingNewLine]", \(mo1 = "\<MO\>"\), ";", 
                "\[IndentingNewLine]", \(mo2 = StringJoin[mo1, Nxstr]\), ";", 
                "\[IndentingNewLine]", \(mo3 = StringJoin[mo2, \ Nystr]\), 
                ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(mo4 = "\< BE=FU,FI  GA=FU,FI  \
PS=DI,FR \>"\), ";", 
                "\[IndentingNewLine]", \(mo = TF[StringJoin[mo3, \ mo4]]\), 
                ";", "\[IndentingNewLine]", \(Write[file2, \ mo]\), ";", 
                "\[IndentingNewLine]", \(pa1 = TF["\<PA BE \n*\>"]\), ";", 
                "\[IndentingNewLine]", \(pa2 = TF["\<PA GA \n*\>"]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, pa1]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(line = OF[MatrixForm[lisBeta]]\), 
                ";", "\[IndentingNewLine]", \(Write[file2, \ \ line\ \ ]\), 
                ";", "\[IndentingNewLine]", \(Write[file2, pa2]\), ";", 
                "\[IndentingNewLine]", \(line = OF[MatrixForm[lisGamma]]\), 
                ";", "\[IndentingNewLine]", \(Write[file2, \ \ line\ \ ]\), 
                ";", "\[IndentingNewLine]", \(ouLine = 
                  TF["\<OU ME=ML   XM  SS GF = 'Fit.TXT' IT=250\>"]\), ";", 
                "\[IndentingNewLine]", \(Write[file2, ouLine]\), ";"}]}], 
            "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}]], "Input",
  FontSize->9],

Cell[TextData[{
  "FUNCTION: ",
  StyleBox["corBounds",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["[rmat,Ntot,Ny_]",
    FontColor->RGBColor[0, 0, 1]],
  "\nDetermines the theoretical bounds on a correlation coefficient given all \
other correlations in the matrix"
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(corBounds[rmat_, Ntot_, Ny_, cors_]\), ":=", "\n", 
          RowBox[{"Module", "[", 
            RowBox[{\({tmpRmat, c1, c2}\), ",", "\n", "\n", 
              
              RowBox[{\(rnd[x_] := N[Round[x*1000]/1000]\), ";", 
                "\n", \(TF[x_] := TraditionalForm[x]\), ";", 
                "\n", \(mkCoef[l_, n_] := {\ Rule[l, n]}\), ";", "\n", 
                StyleBox[\(blank2 = "\<\n \>"\),
                  FontSize->9], 
                StyleBox[";",
                  FontSize->9], "\n", 
                "\n", \(line = 
                  TF["\<\n\n\n[9] Bounds on correlations used to assess the \
model's verisimilitude\n\>"]\), ";", "\n", \(Write[file1, line]\), ";", 
                "\n", \(For[i = 1, 
                  i <= Ntot, \(i++\), \n\ \ \ \ \ \ \ For[j = 1, 
                    j <= \((i - 
                          1)\), \(j++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
If[\((j\  \[LessEqual] Ny)\) && \ \((Count[cors, {i, j}] \[NotEqual] 
                            1)\)\  && \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \((Count[cors, {j, i}] \[NotEqual] 
                            1)\), \ \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ tmpRmat = rmat; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ tmpRmat[\([i, 
                            j]\)] = 
                        r; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ tmpRmat[\
\([j, i]\)] = r; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ bounds = \ 
                        Solve[Det[tmpRmat] == 0, 
                          r]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \n\n\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ c1 = 
                        Map[rnd, 
                          Table[Part[Part[Part[bounds, iter], 1], 2], {iter, 
                              1, Length[
                                bounds]}]]; \n\ \ \ \ \ \ \ \ \ \ \ \
\[IndentingNewLine]\ \ \ \ \ c2 = 
                        Table[Part[Part[bounds, iter], 1], {iter, 1, 
                            Length[
                              bounds]}]; \n\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ tempcoef = {{}}; \[IndentingNewLine]\ \ \ \ \ For[iter = 1, 
                        iter\  \[LessEqual] 
                          Length[
                            c2], \(iter++\), \ \ \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \(tempcoef = Join[tempcoef, 
                              mkCoef[r, 
                                c1[\([iter]\)]\ ]\ ];\)\[IndentingNewLine]\ \ \
\ ]; \[IndentingNewLine]\ \ \ \ \ \ bounds = 
                        Rest[tempcoef]; \n\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ rString = StringJoin["\<r[\>", 
                          ToString[
                            i]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
rString = 
                        StringJoin[
                          rString, "\<,\>"]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ rString = StringJoin[rString, 
                          ToString[
                            j]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
rString = 
                        StringJoin[
                          rString, "\<]  = \>"]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ thisR = PaddedForm[
                          rmat[\([i, j]\)], {6, 
                            3}]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ line \
= StringJoin[rString, \ ToString[
                            thisR]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
line = StringJoin[line, blank2]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ line = 
                        TF[StringJoin[line, 
                            ToString[
                              bounds]]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ Write[file1, 
                        line];\ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\n\ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\n\ \ \ \ \ \ ]\)}]}], "\n", "]"}]}], ";"}], 
      "\n", "\n"}]], "Input",
  FontSize->9],

Cell[TextData[{
  "FUNCTION: forbiddenPaths",
  StyleBox["[timeOrder]",
    FontColor->RGBColor[0, 0, 1]],
  "\nDetermines forbidden paths given the direction of time and prior \
theoretical constraints."
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\(\n\)\(forbiddenPaths[timeOrder_] := \n
      Module[{timeLngth, a, b, i, j, ovra, ovrb}, \nomitPaths = {{}}; \n
        timeLngth = Length[timeOrder]; \n\n
        For[ovra = 1, \ 
          ovra \[LessEqual] 
            timeLngth - 
              1, \(ovra++\), \n\ \ \ \ \ \ \ \ \ \ a = \
\(timeOrder[\([timeLngth - ovra + 1]\)]\)[\([2]\)]; \n\ \ \ For[
            ovrb = ovra + 1, 
            ovrb \[LessEqual] 
              timeLngth, \(ovrb++\), \n\ \ \ \ \ \ \ \ b = \
\(timeOrder[\([timeLngth - ovrb + 
                      1]\)]\)[\([2]\)]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ For[
              i = 1, \ i \[LessEqual] 
                Length[a], \ \(i++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ For[j = 1, \ 
                j \[LessEqual] 
                  Length[b], \(j++\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(omitPaths = 
                    Join[omitPaths, {\ {a[\([i]\)], 
                          b[\([j]\)]}\ }\ ];\)\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ ]\n\ \ \ \ \ \ \ \ \ \ \ \ \ ]\n\ \ ]\n]; \n
        omitPaths = 
          Rest[omitPaths]; \n (*Reverse\ the\ order\ so\ that\ the\ dependent\
\ variable\ is\ on\ the\ left*) \n\  (*this\ is\ necessary\ to\ make\ the\ \
order\ consistent\ with\ corList*) \n
        omitPaths = Map[RotateLeft, omitPaths]; \nomitPaths\n]\)\)\)], "Input",\

  FontSize->9],

Cell[TextData[{
  "Begin:  ",
  StyleBox["MAIN PROGRAM",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  CellFrame->True,
  FontSize->9,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{"       ", "\n", 
      RowBox[{
        RowBox[{
          RowBox[{"ans1", "=", 
            RowBox[{
              StyleBox["findPaths",
                FontColor->RGBColor[0, 0, 1]], "[", \(beta, gamma\), "]"}]}], 
          ";"}], "     ", "\[IndentingNewLine]"}]}]], "Input",
  FontSize->9],

Cell[BoxData[{
    RowBox[{"       ", \(modelPaths = ans1[\([1]\)];\)}], "\n", 
    RowBox[{"       ", \(alternativePaths = ans1[\([2]\)];\)}], "\n", 
    RowBox[{"       ", 
      RowBox[{
        RowBox[{"allModels", "=", 
          RowBox[{
            StyleBox["generateModel",
              FontColor->RGBColor[0, 0, 1]], "[", \(beta, gamma, modelPaths, 
            alternativePaths\), "]"}]}], ";"}]}], "\n", 
    RowBox[{
      "       ", \(allModels = MatrixForm[Flatten[allModels, 1]];\)}], "\n", 
  "              "}], "Input",
  FontSize->9],

Cell[BoxData[{
    \(\[IndentingNewLine]\ \ \ \ \ \ \(betagamma = {{9, 
            9}};\)\), "\[IndentingNewLine]", 
    \(\ \ \ \ \ \ \(sigmaArray = {{9}};\)\), "\[IndentingNewLine]", 
    \(\ \ \ \ \ \ \(stdArray = {{9}};\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\ \ \ \ \ \ \(betaBAK = beta;\)\), "\[IndentingNewLine]", 
    \(\ \ \ \ \ \(gammaBAK = gamma;\)\), "\[IndentingNewLine]", 
    \(\ \ \ \ \ \(numberOfModels = \(Dimensions[\ 
            allModels[\([1]\)]]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\ \ \ \ \ \(Nx = \(Dimensions[gamma]\)[\([2]\)];\)\), "\n", 
    \(\ \ \ \ \ \(Ny = \(Dimensions[beta]\)[\([1]\)];\)\), "\n", 
    \(\ \ \ \ \ \(Ntot = Ny + Nx;\)\), "\n", 
    \(\ \ \ \ \ \(varSequence = Range[1, Ntot];\)\)}], "Input",
  FontSize->9],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"For", "[", 
          
          RowBox[{\(i = 1\), ",", \(i \[LessEqual] numberOfModels\), 
            ",", \(i++\), ",", "\[IndentingNewLine]", "     ", 
            RowBox[{
              RowBox[{"bg", "=", 
                RowBox[{
                  StyleBox["checkMatrices",
                    FontColor->RGBColor[0, 0, 1]], 
                  "[", \(\(\(allModels[\([1]\)]\)[\([i]\)]\)[\([1]\)], \
\(\(allModels[\([1]\)]\)[\([i]\)]\)[\([2]\)]\), " ", "]"}]}], ";", 
              "\[IndentingNewLine]", "     ", \(betaBAK = bg[\([1]\)]\), ";", 
              "\[IndentingNewLine]", "    ", \(gammaBAK = bg[\([2]\)]\), ";", 
              "\[IndentingNewLine]", "    ", \(mainTakeCol = bg[\([3]\)]\), 
              ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                
                RowBox[{\(mainTakeCol \[NotEqual] 99\), ",", 
                  "\[IndentingNewLine]", "    ", 
                  
                  RowBox[{\(newOrder = varSequence\), ";", "\n", 
                    "          ", \(newOrder[\([\ 
                          Range[mainTakeCol + 1, 
                            Ntot]]\)] = \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ newOrder[\([\ Range[mainTakeCol + 1, Ntot]]\)] - 
                        1\), ";", "\n", 
                    "           ", \(newOrder[\([mainTakeCol]\)] = Ntot\), 
                    ";", "   ", "\n", "\n", "         ", 
                    RowBox[{"newsigma", "=", 
                      RowBox[{
                        StyleBox["reOrderSigma",
                          FontColor->RGBColor[0, 0, 1]], "[", \(sigma, 
                        newOrder\), "]"}]}], ";", "\[IndentingNewLine]", 
                    "  ", \(sigmaArray = Join[sigmaArray, {newsigma}]\), ";", 
                    "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", \(newsd = stdVec\), ";", 
                    "\[IndentingNewLine]", 
                    StyleBox[\( (*\ rearrange\ standard\ deviations\ *) \),
                      FontColor->RGBColor[1, 0, 0]], 
                    "\[IndentingNewLine]", \(For[iter = 1, 
                      iter \[LessEqual] 
                        Ntot, \(iter++\), \[IndentingNewLine]\(Part[newsd, \ 
                            1, \ newOrder[\([iter]\)]\ ]\  = \
\(stdVec[\([1]\)]\)[\([iter]\)];\)\[IndentingNewLine]]\), ";", 
                    "\[IndentingNewLine]", \(stdArray = 
                      Join[stdArray, {newsd}]\), ";"}]}], 
                "\[IndentingNewLine]", "  ", "]"}], ";", " ", 
              
              StyleBox[\( (*\ 
                  END : \ \(\(If\)\([\)\(\(mainT  akeCol \[NotEqual] 
                        99\)\(,\)\)\)*) \),
                FontColor->RGBColor[1, 0, 0],
                Background->None], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(If[
                mainTakeCol \[Equal] 99, \[IndentingNewLine]sigmaArray = 
                  Join[sigmaArray, {sigma}]; \[IndentingNewLine]stdArray = 
                  Join[stdArray, {stdVec}];\[IndentingNewLine]\ \ ]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "   ", \(betagamma = Join[betagamma, {{betaBAK, gammaBAK}}]\), 
              ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
      StyleBox[\( (*\ 
          END : \ \(\(For\)\([\)\(i = 1, 
              i \[LessEqual] numberOfModels, \(i++\), \)\(\ \)\)*) \),
        FontColor->RGBColor[1, 0, 0]]}]], "Input",
  FontSize->9],

Cell[BoxData[{
    RowBox[{"  ", 
      RowBox[{
        StyleBox[\( (*Take\ off\ leading\ place\ holder\ from\ list\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", 
        "    ", \(betagamma = Rest[betagamma];\)}]}], "\[IndentingNewLine]", 
    RowBox[{
      "   ", \(sigmaArray = Rest[sigmaArray];\)}], "\[IndentingNewLine]", 
    RowBox[{"  ", \(stdArray = Rest[stdArray];\)}], "\[IndentingNewLine]", 
    RowBox[{"   ", \(Clear[allModels];\)}], "\[IndentingNewLine]", 
    RowBox[{"   ", \(allModels = {betagamma};\)}], "\[IndentingNewLine]", 
  "Null"}], "Input",
  FontSize->9],

Cell[BoxData[{
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"corList", "=", 
          RowBox[{
            StyleBox["whichCors",
              FontColor->RGBColor[0, 0, 1]], "[", \(beta, gamma\), "]"}]}], 
        ";"}], "\n"}], "\[IndentingNewLine]", 
    StyleBox[\( (*which\ paths\ are\ forbidden*) \),
      FontColor->RGBColor[1, 0, 
      0]], "\n", \(badPaths = {};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"If", "[", 
        RowBox[{\(Length[timeOrder] > 0\), ",", "\n", "         ", 
          RowBox[{
            RowBox[{"badPaths", "=", 
              RowBox[{
                StyleBox["forbiddenPaths",
                  FontColor->RGBColor[0, 0, 1]], "[", "timeOrder", "]"}]}], 
            ";"}]}], "\n", "]"}], ";"}]}], "Input",
  FontSize->9],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"theoryModel", "=", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["fitModel",
                FontColor->RGBColor[0, 0, 1]], "[", \(beta, gamma, \ sigma, 
              corList\), "]"}], "}"}]}], ";"}], 
      "\[IndentingNewLine]", \( (*\ \ DegreeFreedom\  = \ #\ corr\ available\ \
for\ model\ testing\ in\ Dstar\ \ \ *) \)}], "\[IndentingNewLine]", \
\(DegreeFreedom = \(theoryModel[\([1]\)]\)[\([14]\)];\), \
"\[IndentingNewLine]", "Null"}], "Input",
  FontSize->9],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["printTheoryResults",
          FontColor->RGBColor[0, 0, 1]], "[", "theoryModel", "]"}], 
      ";"}], "\[IndentingNewLine]", "Null"}], "Input",
  FontSize->9],

Cell[BoxData[
    RowBox[{
      RowBox[{"solutions", "=", 
        RowBox[{
          StyleBox["allPaths",
            FontColor->RGBColor[0, 0, 1]], "[", \(allModels, sigmaArray, 
          DegreeFreedom\), "]"}]}], ";"}]], "Input",
  FontSize->9],

Cell[BoxData[{
    \(\(i =. ;\)\), "\n", 
    \(\ \ \(fits = 
        Table[{\(solutions[\([i]\)]\)[\([5]\)], i}, {i, 1, 
            numberOfModels}];\)\), "\n", 
    \(\)}], "Input",
  FontSize->9],

Cell[BoxData[{
    \( (*note\ the\ numberOfModels\ may\ have\ changed\ in\ allPaths\ \
function*) \n\(rmsq = 
        Flatten[\ \ \(#[\([1]\)] &\) /@ \ \ fits\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(fit = \ 
        Length[\ Select[rmsq, # > \(theoryModel[\([1]\)]\)[\([5]\)]\  &]]/
          numberOfModels;\)\)}], "Input",
  FontSize->9],

Cell[BoxData[{
    \(\[IndentingNewLine] (*Print\ Summary\ of\ Results*) \[IndentingNewLine]<< 
      Statistics`DescriptiveStatistics`\), "\n", 
    \(\(line = 
        TF["\<\n\n\n=========================================================\
\>"];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = TF["\<             SUMMARY OF RESULTS\>"];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = 
        TF["\<=========================================================\>"];\)\
\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<\n\nNumber of Identified Alternative Models = \>", 
            ToString[numberOfModels]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(rms = \(theoryModel[\([1]\)]\)[\([5]\)];\)\), "\[IndentingNewLine]", 
    \(\(rms = rnd[rms];\)\), "\[IndentingNewLine]", 
    \(\(line = 
        TF[StringJoin["\<\nRMSr of Theoretical Model = \>", 
            ToString[rms]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(fit = rnd[fit];\)\), "\[IndentingNewLine]", 
    \(\(line = 
        TF[StringJoin["\<\nOverall fit (RMSr(D*) < x% RMSr(~D*) = \>", 
            ToString[\ fit]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = TF["\<\n\nDescriptive Statistics for RMSr\>"];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = TF["\<\n\nMeasures of location\>"];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(rnd[x_] := N[Round[x*1000]/1000];\)\), "\[IndentingNewLine]", 
    \(\(mnrmsq = Mean[rmsq];\)\), "\[IndentingNewLine]", 
    \(\(mnrmsq = rnd[mnrmsq];\)\), "\[IndentingNewLine]", 
    \(\(line = 
        TF[StringJoin["\<Mean RMSr of Corrupted Models = \>", 
            ToString[mnrmsq]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\[IndentingNewLine]", 
    \(\(trim = TrimmedMean[rmsq, \  .20];\)\), "\n", 
    \(\(trim = rnd[trim];\)\), "\[IndentingNewLine]", 
    \(\(line = 
        TF[StringJoin["\<20% Trimmed Mean of RMSr of Corrupted Models = \>", \
\ ToString[trim]]];\)\), "\n", 
    \(\(Write[file1, 
        line];\)\[IndentingNewLine] (*Compute\ 8\ number\ summary\ of\ \
results*) \), "\[IndentingNewLine]", 
    \(\(minx = rnd[Min[rmsq]];\)\), "\n", 
    \(\(line = TF[StringJoin["\<MIN = \>", ToString[minx]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x5 = rnd[InterpolatedQuantile[rmsq, 0.05]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<5thPercentile = \>", \ ToString[x5]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x10 = rnd[InterpolatedQuantile[rmsq, 0.10]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<10thPercentile = \>", \ ToString[x10]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x20 = rnd[InterpolatedQuantile[rmsq, 0.20]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<20thPercentile = \>", \ ToString[x20]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x25 = rnd[InterpolatedQuantile[rmsq, 0.25]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<25thPercentile = \>", \ ToString[x25]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x50 = rnd[Median[rmsq]];\)\), "\n", 
    \(\(line = TF[StringJoin["\<Median = \>", \ ToString[x50]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(x75 = rnd[InterpolatedQuantile[rmsq, 0.75]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<75thPercentile = \>", \ ToString[x75]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(xmax = rnd[Max[rmsq]];\)\), "\n", 
    \(\(line = TF[StringJoin["\<MAX = \>", ToString[xmax]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(line = TF["\<\n\nMeasures of Dispersion\>"];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(xstdv = rnd[StandardDeviationMLE[rmsq]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<Standard Dev. = \>", ToString[xstdv]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\n", 
    \(\(xmedstdv = rnd[MedianDeviation[rmsq]];\)\), "\n", 
    \(\(line = 
        TF[StringJoin["\<Median Dev. = \>", ToString[xmedstdv]]];\)\), "\n", 
    \(\(Write[file1, line];\)\), "\[IndentingNewLine]", 
    \(Null\)}], "Input",
  FontSize->9],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          RowBox[{"If", "[", 
            
            RowBox[{\(printOutput == "\<LONG\>"\), ",", "\[IndentingNewLine]",
               
              RowBox[{"{", "\[IndentingNewLine]", 
                
                RowBox[{\(Open["\<RMSR.txt\>"]\), ";", 
                  "\[IndentingNewLine]", \(line = 
                    TF["\<\n\n\n\
=========================================================\>"]\), ";", 
                  "\n", \(Write[file1, line]\), ";", 
                  "\n", \(line = 
                    TF["\<             DETAILED RESULTS FOR ALTERNATIVE \
MODELS\>"]\), ";", "\n", \(Write[file1, line]\), ";", 
                  "\n", \(line = 
                    TF["\<====================================================\
=====\>"]\), ";", "\n", \(Write[file1, line]\), ";", "\[IndentingNewLine]", 
                  "  ", 
                  RowBox[{"For", "[", 
                    
                    RowBox[{\(p = 1\), ",", 
                      " ", \(p \[LessEqual] numberOfModels\), ",", \(p++\), 
                      ",", "\[IndentingNewLine]", "    ", 
                      RowBox[{
                        RowBox[{
                          StyleBox["printResults",
                            FontColor->RGBColor[0, 0, 1]], "[", \(solutions, 
                          p\), "]"}], ";", " ", "\[IndentingNewLine]", "    ",
                         
                        RowBox[{
                          StyleBox["printLISREL",
                            FontColor->RGBColor[0, 0, 1]], "[", \(solutions, 
                          p\), "]"}], ";", " ", 
                        "\[IndentingNewLine]", \(Write["\<RMSR.txt\>", 
                          rmsq[\([p]\)]]\), ";"}]}], "\[IndentingNewLine]", 
                    "      ", "]"}], ";"}], "\[IndentingNewLine]", "}"}]}], 
            "\[IndentingNewLine]", "]"}], ";"}], 
        "\[IndentingNewLine]"}]}]], "Input",
  FontSize->9],

Cell[BoxData[{
    \(\(Close[file1];\)\), "\[IndentingNewLine]", 
    \(\(Close[file2];\)\), "\[IndentingNewLine]", 
    \(\(Close["\<RMSR.txt\>"];\)\)}], "Input",
  FontSize->9],

Cell[BoxData[""], "Input"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 663}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Presentation",
PrintingStyleEnvironment->"Working",
WindowSize->{1014, 636},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
Magnification->2
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 5467, 161, 1727, "Text"],
Cell[7175, 213, 182, 5, 41, "Input",
  CellOpen->False,
  InitializationCell->True],
Cell[7360, 220, 182, 7, 103, "Text"],
Cell[7545, 229, 166, 4, 113, "Input"],
Cell[7714, 235, 173, 7, 103, "Text"],
Cell[7890, 244, 98, 2, 102, "Text"],
Cell[7991, 248, 1228, 27, 553, "Text"],
Cell[9222, 277, 306, 6, 141, "Input"],
Cell[9531, 285, 161, 4, 103, "Text"],
Cell[9695, 291, 467, 12, 301, "Input"],
Cell[10165, 305, 1211, 22, 553, "Text"],
Cell[11379, 329, 27767, 457, 5625, "Input"],
Cell[39149, 788, 110, 3, 103, "Text"],
Cell[39262, 793, 624, 14, 223, "Text"],
Cell[39889, 809, 2785, 51, 893, "Input"],
Cell[42677, 862, 463, 12, 163, "Text"],
Cell[43143, 876, 7712, 122, 1907, "Input"],
Cell[50858, 1000, 345, 12, 133, "Text"],
Cell[51206, 1014, 3074, 60, 1127, "Input"],
Cell[54283, 1076, 588, 13, 223, "Text"],
Cell[54874, 1091, 3762, 68, 1361, "Input"],
Cell[58639, 1161, 373, 10, 163, "Text"],
Cell[59015, 1173, 9386, 170, 2141, "Input"],
Cell[68404, 1345, 192, 8, 133, "Text"],
Cell[68599, 1355, 4291, 77, 2011, "Input"],
Cell[72893, 1434, 200, 8, 133, "Text"],
Cell[73096, 1444, 7331, 135, 3857, "Input"],
Cell[80430, 1581, 219, 8, 103, "Text"],
Cell[80652, 1591, 9831, 171, 3285, "Input"],
Cell[90486, 1764, 350, 11, 133, "Text"],
Cell[90839, 1777, 3921, 74, 1309, "Input"],
Cell[94763, 1853, 285, 9, 133, "Text"],
Cell[95051, 1864, 1388, 29, 633, "Input"],
Cell[96442, 1895, 171, 7, 103, "Text"],
Cell[96616, 1904, 321, 9, 113, "Input"],
Cell[96940, 1915, 553, 13, 165, "Input"],
Cell[97496, 1930, 786, 14, 347, "Input"],
Cell[98285, 1946, 3613, 68, 841, "Input"],
Cell[101901, 2016, 593, 12, 217, "Input"],
Cell[102497, 2030, 796, 20, 243, "Input"],
Cell[103296, 2052, 551, 13, 139, "Input"],
Cell[103850, 2067, 220, 6, 87, "Input"],
Cell[104073, 2075, 249, 7, 61, "Input"],
Cell[104325, 2084, 199, 6, 113, "Input"],
Cell[104527, 2092, 342, 8, 113, "Input"],
Cell[104872, 2102, 4222, 87, 1855, "Input"],
Cell[109097, 2191, 1999, 42, 503, "Input"],
Cell[111099, 2235, 178, 4, 113, "Input"],
Cell[111280, 2241, 26, 0, 76, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

